@@ -9,6 +9,7 @@
 #define KPAGEWIDGETMODEL_H
 
 #include "kpagemodel.h"
+#include <memory>
 
 class QWidget;
 
@@ -71,7 +72,7 @@ public:
     /**
      * Destroys the page widget item.
      */
-    ~KPageWidgetItem();
+    ~KPageWidgetItem() override;
 
     /**
      * Returns the widget of the page widget item.
@@ -96,10 +97,6 @@ public:
      * does not got set explicit, then the defined name() will also be used
      * for the header.
      *
-     * For backward-compatibility, if setHeader("") is used, the header will be hidden
-     * even if the @a KPageView::FaceType is something else then Tabbed.
-     * This feature is deprecated since 5.52. use @c setHeaderVisible(false) instead.
-     *
      * @param header Header of the page widget item.
      */
     void setHeader(const QString &header);
@@ -179,8 +176,7 @@ Q_SIGNALS:
     void toggled(bool checked);
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<class KPageWidgetItemPrivate> const d;
 };
 
 class KPageWidgetModelPrivate;
